@@ -191,6 +191,14 @@ def escape_file_path(path):
 	path = path.replace('?', '-')
 	return path
 
+def join_video(flvs, outfile):  # only work on linux 64bit
+    import commands
+    cmd = 'fastreaming '
+    for f in flvs:
+        cmd = cmd + ' -i ' + f
+    cmd = cmd + ' -o ' + outfile
+    return commands.getstatusoutput(cmd)[0]
+
 def download_urls(urls, title, ext, total_size, output_dir='.', refer=None, merge=True):
 	assert urls
 	assert ext in ('flv', 'mp4')
@@ -231,6 +239,13 @@ def download_urls(urls, title, ext, total_size, output_dir='.', refer=None, merg
 		bar.done()
 		if not merge:
 			return
+
+                #merge_result = join_video(flvs, os.path.join(output_dir, title+"."+ext))
+                #for flv in flvs:
+                #    os.remove(flv)
+                #if merge_result!=0:
+                #    print 'Merge error'
+
 		if ext == 'flv':
 			from flv_join import concat_flvs
 			concat_flvs(flvs, os.path.join(output_dir, title+'.flv'))
