@@ -23,7 +23,9 @@ def real_url(url):
 	return url2
 
 def real_url2(url): 
-	return url.replace('http://data.video.qiyi.com/videos', 'http://wgdcdn.inter.qiyi.com/videos2')
+	url= url.replace('http://data.video.qiyi.com/videos', 'http://wgdcdn.inter.qiyi.com/videos2')
+        url= url + '&ct=3'
+        return url
 
 def iqiyi_download(url, merge=True):
 	html = get_html(url)
